Alice class

Constructors

Alice({AliceConfiguration? configuration})
Creates alice instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
isInspectorOpened bool
Returns flag which determines whether inspector is opened
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAdapter(AliceAdapter adapter) → void
Adds new adapter to Alice.
addHttpCall(AliceHttpCall aliceHttpCall) → void
Handle generic http call. Can be used to any http client.
addLog(AliceLog log) → void
Adds new log to Alice logger.
addLogs(List<AliceLog> logs) → void
Adds list of logs to Alice logger
getNavigatorKey() GlobalKey<NavigatorState>?
Get currently used navigation key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNavigatorKey(GlobalKey<NavigatorState> navigatorKey) → void
Set custom navigation key. This will help if there's route library.
showInspector() → void
Opens Http calls inspector. This will navigate user to the new fullscreen page where all listened http calls can be viewed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited